From: Jay Liu <jay.liu@mediatek.com>
To: <igt-dev@lists.freedesktop.org>
Cc: Jason-JH Lin <jason-jh.lin@mediatek.com>,
Paul-PL Chen <paul-pl.chen@mediatek.com>,
Nancy Lin <nancy.lin@mediatek.com>,
Singo Chang <singo.chang@mediatek.com>,
Gil Dekel <gildekel@google.com>, Yacoub <markyacoub@chromium.org>,
Sharma Swati2 <swati2.sharma@intel.com>,
<Project_Global_Chrome_Upstream_Group@mediatek.com>,
Jay Liu <jay.liu@mediatek.com>
Subject: [PATCH v4 1/1] tests/kms_color: Add 10-bit color depth support to gamma test for MediaTek
Date: Sun, 31 May 2026 11:17:05 +0800 [thread overview]
Message-ID: <20260531031732.16600-2-jay.liu@mediatek.com> (raw)
In-Reply-To: <20260531031732.16600-1-jay.liu@mediatek.com>
1. Add 10-bit color depth flow to gamma test for MediaTek devices, which only support bit-true results with 10-bit data. The test now selects 8-bit or 10-bit color depth and framebuffer format based on device type.
2. To satisfy the legacy gamma test requirements, the MTK Gamma LUT limit should be set to 4092, in the current 16-bit LUT design, setting the entry to 0xffd0 ensures the driver maps it correctly to 4092.
Signed-off-by: Jay Liu <jay.liu@mediatek.com>
---
tests/kms_color.c | 34 ++++++++++++++++++++++++++++------
1 file changed, 28 insertions(+), 6 deletions(-)
diff --git a/tests/kms_color.c b/tests/kms_color.c
index 565edb2dc..4c32591aa 100644
--- a/tests/kms_color.c
+++ b/tests/kms_color.c
@@ -265,6 +265,7 @@ static bool test_pipe_legacy_gamma(data_t *data,
drmModeCrtc *drm_crtc;
uint32_t i, legacy_lut_size;
uint16_t *red_lut, *green_lut, *blue_lut;
+ uint16_t lut_value;
drmModeModeInfo *mode = data->mode;
struct igt_fb fb_modeset, fb;
igt_crc_t crc_fullgamma, crc_fullcolors;
@@ -288,7 +289,7 @@ static bool test_pipe_legacy_gamma(data_t *data,
fb_id = igt_create_fb(data->drm_fd,
mode->hdisplay,
mode->vdisplay,
- DRM_FORMAT_XRGB8888,
+ data->drm_format,
DRM_FORMAT_MOD_LINEAR,
&fb);
igt_assert(fb_id);
@@ -296,7 +297,7 @@ static bool test_pipe_legacy_gamma(data_t *data,
fb_modeset_id = igt_create_fb(data->drm_fd,
mode->hdisplay,
mode->vdisplay,
- DRM_FORMAT_XRGB8888,
+ data->drm_format,
DRM_FORMAT_MOD_LINEAR,
&fb_modeset);
igt_assert(fb_modeset_id);
@@ -321,9 +322,22 @@ static bool test_pipe_legacy_gamma(data_t *data,
paint_gradient_rectangles(data, mode, red_green_blue, &fb);
igt_plane_set_fb(primary, &fb);
+ /*
+ * The Medaitek Gamma LUT maps 10bit input data to 12bit output.
+ * In this test case, the maximum input value is 1023.
+ * When the Gamma function is disabled, the data defaults to a 4092 output.
+ * To achieve bit true results, the Gamma LUT maximum must be set to 4092.
+ * Note that 0xFFFD0 represents 16-bit,which maps to 4092 in 12-bit depth.
+ */
+ if (is_mtk_device(data->drm_fd))
+ lut_value = 0xffd0;
+ else
+ lut_value = 0xffff;
+
red_lut[0] = green_lut[0] = blue_lut[0] = 0;
for (i = 1; i < legacy_lut_size; i++)
- red_lut[i] = green_lut[i] = blue_lut[i] = 0xffff;
+ red_lut[i] = green_lut[i] = blue_lut[i] = lut_value;
+
igt_assert_eq(drmModeCrtcSetGamma(data->drm_fd, primary->crtc->crtc_id,
legacy_lut_size, red_lut, green_lut, blue_lut), 0);
igt_display_commit(&data->display);
@@ -752,14 +766,22 @@ static void
run_gamma_degamma_tests_for_crtc(data_t *data, igt_crtc_t *crtc,
bool (*test_t)(data_t*, igt_plane_t*))
{
+ bool depth_10bit = false;
+
test_setup(data, crtc);
+ /* MediaTek requires 10-bit pipeline for accurate (bit true) color processing */
+ if (is_mtk_device(data->drm_fd))
+ depth_10bit = true;
+
/*
* We assume an 8bits depth per color for degamma/gamma LUTs
* for CRC checks with framebuffer references.
*/
- data->color_depth = 8;
- data->drm_format = DRM_FORMAT_XRGB8888;
+
+ /* MediaTek requires 10-bit pipeline for accurate (bit true) color processing */
+ data->color_depth = depth_10bit ? 10 : 8;
+ data->drm_format = depth_10bit ? DRM_FORMAT_XRGB2101010 : DRM_FORMAT_XRGB8888;
data->mode = igt_output_get_mode(data->output);
igt_require(crtc_output_combo_valid(data, crtc));
@@ -752,14 +766,22 @@ static void
/*
- * We assume an 8bits depth per color for degamma/gamma LUTs
+ * We assume an 8bits or 10bits depth per color for degamma/gamma LUTs
* for CRC checks with framebuffer references.
*/
--
2.46.0
next prev parent reply other threads:[~2026-05-31 3:18 UTC|newest]
Thread overview: 7+ messages / expand[flat|nested] mbox.gz Atom feed top
2026-05-31 3:17 [PATCH i-g-t v4 0/1] tests/kms_color: Add 10-bit color depth support to gamma test for MediaTek Jay Liu
2026-05-31 3:17 ` Jay Liu [this message]
2026-06-02 19:52 ` [PATCH v4 1/1] " Sharma, Swati2
2026-05-31 3:59 ` ✓ Xe.CI.BAT: success for " Patchwork
2026-05-31 4:13 ` ✓ i915.CI.BAT: " Patchwork
2026-05-31 5:12 ` ✗ Xe.CI.FULL: failure " Patchwork
2026-05-31 6:18 ` ✗ i915.CI.Full: " Patchwork
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20260531031732.16600-2-jay.liu@mediatek.com \
--to=jay.liu@mediatek.com \
--cc=Project_Global_Chrome_Upstream_Group@mediatek.com \
--cc=gildekel@google.com \
--cc=igt-dev@lists.freedesktop.org \
--cc=jason-jh.lin@mediatek.com \
--cc=markyacoub@chromium.org \
--cc=nancy.lin@mediatek.com \
--cc=paul-pl.chen@mediatek.com \
--cc=singo.chang@mediatek.com \
--cc=swati2.sharma@intel.com \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox